//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[RegularShantenResult](index.md)/[RegularShantenResult](-regular-shanten-result.md)

# RegularShantenResult

[common]\
constructor(hand: [Hand](../../mahjongutils.models.hand/-hand/index.md)&lt;[RegularHandPattern](../../mahjongutils.models.hand/-regular-hand-pattern/index.md)&gt;, shantenInfo: [CommonShanten](../-common-shanten/index.md))
